<!-- Copyright © SixtyFPS GmbH <info@slint.dev> ; SPDX-License-Identifier: MIT -->
# Comments

C-style comments are supported:

-   line comments: `//` means everything to the end of the line is commented.
-   block comments: `/* .. */`. Note that the blocks comments can be nested, so `/* this is a /* single */ comment */`
